%Script for ADV data analysis
%Jaco de Smit -- 10-04-2018

clear variables
close all

% Copy path to folder containing ADV data
Foldername = 'folder with ADV files'; 
addpath(Foldername);
files=dir([Foldername,'\*.mat']);
numfiles = length(files);

%allocating things
Filename = cell(1,numfiles);
X_meandist = cell(1,numfiles);
Y_meandist = cell(1,numfiles);
Z_meandist = cell(1,numfiles);
U_meandist = cell(1,numfiles);
XYZ_meandist = cell(1,numfiles);
X_mediantime = cell(1,numfiles);
Y_mediantime = cell(1,numfiles);
Z_mediantime = cell(1,numfiles);
Profrange = cell(1,numfiles);
TKE = cell(1,numfiles);
BSS_TKE = cell(1,numfiles);
X_filt0 = cell(1,numfiles);
Spectrum_S = cell(1,numfiles);
Spectrum_F = cell(1,numfiles);
u_max = zeros(1,numfiles);
u_rms = zeros(1,numfiles);
u_max2 = zeros(1,numfiles);
u_rms2 = zeros(1,numfiles);
fw = cell(1,numfiles);
Timeax = cell(1,numfiles);
U_mediantimedist = zeros(1,numfiles);
U_stdtimedist = zeros(1,numfiles);

%Number of velocity settings used
numspeeds = 10;

%Band stops for filtering data to calculate turbulence (see manual)
Highpass = 0.4;
Lowpass = 10;

%Number of blocks that you use for the variance density spectrum
nb = 20;

%Filters
SNRfilter = 30; %Filter for Signal To Noise Ratio
AMPfilter = -40; %Filter for Reflection Amplitude
Corrfilter = 90; %Filter for Correlation

h=waitbar(0,'busy');

%Manual entries for wave period, minimum peak velocities to consider for
%average, and timestamps during which erosion was observed
T = ones(1,numfiles).*4;
u_est = [0.15 0.15 0.15 0.15 0.20 0.18 0.15 0.20 0.18 0.15 0.20 0.18 0.15 0.20 0.15 0.10 0.20 0.15 0.10 0.20 0.15 0.10 0.12 0.12 0.12 0.12 0.12];
left = [300 265 200 230 370 260 490 860 380 215 155 120 140 125 122 60 125 120 31 250 55 107 240 170 160 125 115];
right = [330 290 270 280 405 300 540 890 410 260 195 140 180 185 170 130 165 150 105 295 112 155 340 230 210 180 150];

for i = 1:numfiles
    
    waitbar(i/numfiles,h)
    Filename{i} = files(i).name;
    load(Filename{i}); 
    freq = Config.sampleRate;
    
    [Data, X_meandist{i}, Y_meandist{i}, Z_meandist{i}, U_meandist{i},...
        X_mediantime{i}, Y_mediantime{i}, Z_mediantime{i}, Profrange{i}] = ...
    ADVdataMain(Config,Data,SNRfilter,AMPfilter,Corrfilter,Datatype);
    
    [Data, TKE{i}, BSS_TKE{i}, Spectrum_S{i}, Spectrum_F{i}, u_max(i), u_rms(i), nfft(i), edf(i), nBlocks(i), peaksvar(i)] =...
    Waveparam(Data, U_meandist{i}, Lowpass, Highpass, freq, nb, T(i), u_est(i));
    
    %Generate a time axis for plots
    Timeax{i} = round([1/freq:1/freq:length(X_meandist{i})/freq]',2);
    
    % figures
    figure;
    plot(Timeax{i},U_meandist{i});

    [Peaks{i}, locs{i}, w{i}, p{i}] = findpeaks(abs(U_meandist{i}(find(Timeax{i} == left(i)):find(Timeax{i} == right(i)))),'MinPeakDistance',T(i)/4*freq,'MinPeakHeight',u_est(i));
    u_max(i) = median(Peaks{i}(p{i}<0.4));
    peaksvar(i) = std(Peaks{i}(p{i}<0.4));
    T(i) = (locs{i}(end)-locs{i}(1))/(length(locs{i})-1)/freq*2;

end
close(h)

